-file("/usr/local/Cellar/erlang/25.2/lib/erlang/lib/parsetools-2.4.1/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(redbug_lexer).

-export([string/1,string/2,token/2,token/3,tokens/2,tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 111).

%% @hidden

to_atom(Str) ->
    list_to_atom(Str).

char_to_int([$$, C]) ->
    C.

radix_to_int(Str) ->
    case erl_scan:tokens([], Str++". ", 0) of
        {done, {ok, [{integer, _, Int}, {dot, _}], 0}, []} -> Int;
        _ -> throw({error, {0, ?MODULE, "malformed_int: "++Str}, 0})
    end.

int_to_int(Str) ->
    list_to_integer(Str).

to_binary(Str) ->
    try
        {done, {ok, Toks, _}, []} = erl_scan:tokens([], Str++". ", 0),
        {ok, Exprs} = erl_parse:parse_exprs(Toks),
        {value, Val, _} = erl_eval:exprs(Exprs, erl_eval:new_bindings()),
        Val
    catch
        _:_ -> throw({error, {0, ?MODULE, "malformed_binary: "++Str}, 0})
    end.

trim(Str) ->
    lists:reverse(tl(lists:reverse(tl(Str)))).

-file("/usr/local/Cellar/erlang/25.2/lib/erlang/lib/parsetools-2.4.1/include/leexinc.hrl", 14).

format_error({illegal,S}) -> ["illegal characters ",io_lib:write_string(S)];
format_error({user,S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

string([], L, [], Ts) ->                     % No partial tokens!
    {ok,yyrev(Ts),L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        {A,Alen,Ics1,L1} ->                  % Accepting end state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {A,Alen,Ics1,L1,_S1} ->              % Accepting transition state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {reject,_Alen,Tlen,_Ics1,L1,_S1} ->  % After a non-accepting state
            {error,{L0,?MODULE,{illegal,yypre(Tcs, Tlen+1)}},L1};
        {A,Alen,Tlen,_Ics1,L1,_S1} ->
            Tcs1 = yysuf(Tcs, Alen),
            L2 = adjust_line(Tlen, Alen, Tcs1, L1),
            string_cont(Tcs1, L2, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

-dialyzer({nowarn_function, string_cont/4}).

string_cont(Rest, Line, {token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, {end_token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error,S}, _Ts) ->
    {error,{Line,?MODULE,{user,S}},Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token,State,Line,Tcs,Tlen,Tline,Action,Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{token,S1,L1,Tcs,Alen1,Tline,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{token,S1,L1,Tcs,Tlen1,Tline,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     true -> {eof,L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,Ics1,L1,_S1} ->    % No token match
            Error = {Tline,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            {done,{error,Error,L1},Ics1};
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->       % Use last accept match
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            token_cont(Tcs1, L2, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

-dialyzer({nowarn_function, token_cont/3}).

token_cont(Rest, Line, {token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, {end_token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {end_token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token,Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error,S}) ->
    {done,{error,{Line,?MODULE,{user,S}},Line},Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens,State,Line,Tcs,Tlen,Tline,Ts,Action,Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens,State,Line,Tcs,Tlen,Tline,Error,Action,Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Alen1,Tline,Ts,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Tlen1,Tline,Ts,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error, no need to skip here.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     Ts == [] -> {eof,L1};
                     true -> {ok,yyrev(Ts),L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            %% Skip rest of tokens.
            Error = {L1,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            tokens_cont(Tcs1, L2, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

-dialyzer({nowarn_function, tokens_cont/4}).

tokens_cont(Rest, Line, {token,T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {end_token,T}, Ts) ->
    {done,{ok,yyrev(Ts, [T]),Line},Rest};
tokens_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done,{ok,yyrev(Ts, [T]),Line},NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error,S}, _Ts) ->
    skip_tokens(Rest, Line, {Line,?MODULE,{user,S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        {A1,Alen1,Ics1,L1} ->                  % Accepting end state
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,[],L1,S1} ->                 % After an accepting state
            {more,{skip_tokens,S1,L1,Tcs,Alen1,Tline,Error,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,Tlen1,[],L1,S1} ->           % After a non-accepting state
            {more,{skip_tokens,S1,L1,Tcs,Tlen1,Tline,Error,A1,Alen1}};
        {reject,_Alen1,_Tlen1,eof,L1,_S1} ->
            {done,{error,Error,L1},eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            skip_cont(Tcs1, L2, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

-dialyzer({nowarn_function, skip_cont/4}).

skip_cont(Rest, Line, {token,_T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token,_T}, Error) ->
    {done,{error,Error,Line},Rest};
skip_cont(Rest, Line, {end_token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    {done,{error,Error,Line},NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error,_S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

-compile({nowarn_unused_function, [yyrev/1, yyrev/2, yypre/2, yysuf/2]}).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% adjust_line(TokenLength, AcceptLength, Chars, Line) -> NewLine
%% Make sure that newlines in Chars are not counted twice.
%% Line has been updated with respect to newlines in the prefix of
%% Chars consisting of (TokenLength - AcceptLength) characters.

-compile({nowarn_unused_function, adjust_line/4}).

adjust_line(N, N, _Cs, L) -> L;
adjust_line(T, A, [$\n|Cs], L) ->
    adjust_line(T-1, A, Cs, L-1);
adjust_line(T, A, [_|Cs], L) ->
    adjust_line(T-1, A, Cs, L).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("/Users/masse/git/redbug/src/redbug_lexer.erl", 337).
yystate() -> 244.

yystate(259, [43|Ics], Line, Tlen, _, _) ->
    yystate(228, Ics, Line, Tlen+1, 11, Tlen);
yystate(259, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,259};
yystate(258, [109|Ics], Line, Tlen, _, _) ->
    yystate(242, Ics, Line, Tlen+1, 19, Tlen);
yystate(258, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(258, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(258, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(258, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 108 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(258, [C|Ics], Line, Tlen, _, _) when C >= 110, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(258, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,258};
yystate(257, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(257, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(248, Ics, Line, Tlen+1, Action, Alen);
yystate(257, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(216, Ics, Line, Tlen+1, Action, Alen);
yystate(257, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(257, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(257, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(257, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(257, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,257};
yystate(256, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(256, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(208, Ics, Line, Tlen+1, Action, Alen);
yystate(256, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(240, Ics, Line, Tlen+1, Action, Alen);
yystate(256, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(256, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(256, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(256, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(256, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(256, Ics, Line, Tlen+1, Action, Alen);
yystate(256, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,256};
yystate(255, [101|Ics], Line, Tlen, _, _) ->
    yystate(239, Ics, Line, Tlen+1, 19, Tlen);
yystate(255, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(255, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(255, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(255, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(255, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(255, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,255};
yystate(254, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(254, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(254, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(254, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,254};
yystate(253, [111|Ics], Line, Tlen, _, _) ->
    yystate(237, Ics, Line, Tlen+1, 19, Tlen);
yystate(253, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(253, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(253, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(253, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(253, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(253, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,253};
yystate(252, [10|Ics], Line, Tlen, _, _) ->
    yystate(252, Ics, Line+1, Tlen+1, 0, Tlen);
yystate(252, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(252, Ics, Line, Tlen+1, 0, Tlen);
yystate(252, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 32 ->
    yystate(252, Ics, Line, Tlen+1, 0, Tlen);
yystate(252, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line,252};
yystate(251, [101|Ics], Line, Tlen, _, _) ->
    yystate(180, Ics, Line, Tlen+1, 19, Tlen);
yystate(251, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(251, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(251, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(251, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(251, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(251, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,251};
yystate(250, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(254, Ics, Line, Tlen+1, Action, Alen);
yystate(250, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(238, Ics, Line, Tlen+1, Action, Alen);
yystate(250, [32|Ics], Line, Tlen, Action, Alen) ->
    yystate(166, Ics, Line, Tlen+1, Action, Alen);
yystate(250, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(166, Ics, Line, Tlen+1, Action, Alen);
yystate(250, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line+1, Tlen+1, Action, Alen);
yystate(250, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(250, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 31 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(250, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 126 ->
    yystate(166, Ics, Line, Tlen+1, Action, Alen);
yystate(250, [C|Ics], Line, Tlen, Action, Alen) when C >= 127 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(250, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,250};
yystate(249, [109|Ics], Line, Tlen, _, _) ->
    yystate(255, Ics, Line, Tlen+1, 19, Tlen);
yystate(249, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(249, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(249, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(249, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 108 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(249, [C|Ics], Line, Tlen, _, _) when C >= 110, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(249, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,249};
yystate(248, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(232, Ics, Line, Tlen+1, Action, Alen);
yystate(248, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,248};
yystate(247, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(247, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(247, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(247, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(247, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(247, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(247, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(247, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(247, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(247, [C|Ics], Line, Tlen, Action, Alen) when C >= 45, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(247, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(247, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(247, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,247};
yystate(246, [117|Ics], Line, Tlen, _, _) ->
    yystate(258, Ics, Line, Tlen+1, 19, Tlen);
yystate(246, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(246, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(246, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(246, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 116 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(246, [C|Ics], Line, Tlen, _, _) when C >= 118, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(246, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,246};
yystate(245, [62|Ics], Line, Tlen, _, _) ->
    yystate(228, Ics, Line, Tlen+1, 11, Tlen);
yystate(245, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(205, Ics, Line, Tlen+1, 11, Tlen);
yystate(245, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,245};
yystate(244, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(228, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(228, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(228, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [121|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [122|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(212, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [119|Ics], Line, Tlen, Action, Alen) ->
    yystate(148, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [117|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [118|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [116|Ics], Line, Tlen, Action, Alen) ->
    yystate(84, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [115|Ics], Line, Tlen, Action, Alen) ->
    yystate(4, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [114|Ics], Line, Tlen, Action, Alen) ->
    yystate(91, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [112|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [113|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [111|Ics], Line, Tlen, Action, Alen) ->
    yystate(187, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [110|Ics], Line, Tlen, Action, Alen) ->
    yystate(253, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [109|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [108|Ics], Line, Tlen, Action, Alen) ->
    yystate(197, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [106|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [107|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [105|Ics], Line, Tlen, Action, Alen) ->
    yystate(117, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [104|Ics], Line, Tlen, Action, Alen) ->
    yystate(139, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [102|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [103|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [101|Ics], Line, Tlen, Action, Alen) ->
    yystate(217, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [100|Ics], Line, Tlen, Action, Alen) ->
    yystate(191, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [99|Ics], Line, Tlen, Action, Alen) ->
    yystate(164, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [98|Ics], Line, Tlen, Action, Alen) ->
    yystate(159, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [97|Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(88, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [93|Ics], Line, Tlen, Action, Alen) ->
    yystate(228, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [91|Ics], Line, Tlen, Action, Alen) ->
    yystate(228, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(104, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [61|Ics], Line, Tlen, Action, Alen) ->
    yystate(120, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [60|Ics], Line, Tlen, Action, Alen) ->
    yystate(160, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(228, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(93, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(141, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(157, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(189, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [48|Ics], Line, Tlen, Action, Alen) ->
    yystate(205, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(213, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(245, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(228, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(259, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(243, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [41|Ics], Line, Tlen, Action, Alen) ->
    yystate(228, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(228, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(211, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [36|Ics], Line, Tlen, Action, Alen) ->
    yystate(195, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(163, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(236, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(252, Ics, Line+1, Tlen+1, Action, Alen);
yystate(244, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(252, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(252, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [C|Ics], Line, Tlen, Action, Alen) when C >= 52, C =< 57 ->
    yystate(173, Ics, Line, Tlen+1, Action, Alen);
yystate(244, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 90 ->
    yystate(88, Ics, Line, Tlen+1, Action, Alen);
yystate(244, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,244};
yystate(243, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line};
yystate(242, [98|Ics], Line, Tlen, _, _) ->
    yystate(226, Ics, Line, Tlen+1, 19, Tlen);
yystate(242, [97|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(242, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(242, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(242, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(242, [C|Ics], Line, Tlen, _, _) when C >= 99, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(242, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,242};
yystate(241, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(241, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(241, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line+1, Tlen+1, Action, Alen);
yystate(241, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(241, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(241, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(241, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(241, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,241};
yystate(240, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(256, Ics, Line, Tlen+1, Action, Alen);
yystate(240, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,240};
yystate(239, [110|Ics], Line, Tlen, _, _) ->
    yystate(223, Ics, Line, Tlen+1, 19, Tlen);
yystate(239, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(239, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(239, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(239, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(239, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(239, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,239};
yystate(238, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(238, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(222, Ics, Line, Tlen+1, Action, Alen);
yystate(238, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(198, Ics, Line, Tlen+1, Action, Alen);
yystate(238, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(238, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(238, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(238, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(238, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,238};
yystate(237, [116|Ics], Line, Tlen, _, _) ->
    yystate(221, Ics, Line, Tlen+1, 19, Tlen);
yystate(237, [100|Ics], Line, Tlen, _, _) ->
    yystate(27, Ics, Line, Tlen+1, 19, Tlen);
yystate(237, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(237, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(237, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(237, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 99 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(237, [C|Ics], Line, Tlen, _, _) when C >= 101, C =< 115 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(237, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(237, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,237};
yystate(236, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(188, Ics, Line, Tlen+1, Action, Alen);
yystate(236, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(220, Ics, Line, Tlen+1, Action, Alen);
yystate(236, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(236, Ics, Line+1, Tlen+1, Action, Alen);
yystate(236, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(236, Ics, Line, Tlen+1, Action, Alen);
yystate(236, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(236, Ics, Line, Tlen+1, Action, Alen);
yystate(236, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(236, Ics, Line, Tlen+1, Action, Alen);
yystate(236, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(236, Ics, Line, Tlen+1, Action, Alen);
yystate(236, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,236};
yystate(235, [115|Ics], Line, Tlen, _, _) ->
    yystate(251, Ics, Line, Tlen+1, 19, Tlen);
yystate(235, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(235, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(235, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(235, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 114 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(235, [C|Ics], Line, Tlen, _, _) when C >= 116, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(235, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,235};
yystate(234, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(234, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(234, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line+1, Tlen+1, Action, Alen);
yystate(234, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(234, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(234, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(234, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(218, Ics, Line, Tlen+1, Action, Alen);
yystate(234, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(234, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(234, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,234};
yystate(233, [101|Ics], Line, Tlen, _, _) ->
    yystate(249, Ics, Line, Tlen+1, 19, Tlen);
yystate(233, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(233, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(233, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(233, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(233, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(233, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,233};
yystate(232, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(232, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(248, Ics, Line, Tlen+1, Action, Alen);
yystate(232, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(216, Ics, Line, Tlen+1, Action, Alen);
yystate(232, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(232, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(232, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(232, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(232, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(232, Ics, Line, Tlen+1, Action, Alen);
yystate(232, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,232};
yystate(231, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(95, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(111, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(135, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [48|Ics], Line, Tlen, Action, Alen) ->
    yystate(151, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(167, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [36|Ics], Line, Tlen, Action, Alen) ->
    yystate(183, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(215, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line+1, Tlen+1, Action, Alen);
yystate(231, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [C|Ics], Line, Tlen, Action, Alen) when C >= 37, C =< 44 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [C|Ics], Line, Tlen, Action, Alen) when C >= 52, C =< 57 ->
    yystate(127, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(231, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(231, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,231};
yystate(230, [100|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 19, Tlen);
yystate(230, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(230, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(230, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(230, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 99 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(230, [C|Ics], Line, Tlen, _, _) when C >= 101, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(230, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,230};
yystate(229, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line};
yystate(228, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line};
yystate(227, Ics, Line, Tlen, _, _) ->
    {20,Tlen,Ics,Line};
yystate(226, [101|Ics], Line, Tlen, _, _) ->
    yystate(46, Ics, Line, Tlen+1, 19, Tlen);
yystate(226, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(226, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(226, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(226, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(226, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(226, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,226};
yystate(225, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(152, Ics, Line, Tlen+1, Action, Alen);
yystate(225, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(136, Ics, Line, Tlen+1, Action, Alen);
yystate(225, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(112, Ics, Line, Tlen+1, Action, Alen);
yystate(225, [48|Ics], Line, Tlen, Action, Alen) ->
    yystate(96, Ics, Line, Tlen+1, Action, Alen);
yystate(225, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(80, Ics, Line, Tlen+1, Action, Alen);
yystate(225, [36|Ics], Line, Tlen, Action, Alen) ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(225, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(225, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line+1, Tlen+1, Action, Alen);
yystate(225, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(225, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(225, [C|Ics], Line, Tlen, Action, Alen) when C >= 52, C =< 57 ->
    yystate(128, Ics, Line, Tlen+1, Action, Alen);
yystate(225, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,225};
yystate(224, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(224, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(208, Ics, Line, Tlen+1, Action, Alen);
yystate(224, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(240, Ics, Line, Tlen+1, Action, Alen);
yystate(224, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(224, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(224, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(224, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(224, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(224, Ics, Line, Tlen+1, Action, Alen);
yystate(224, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,224};
yystate(223, [116|Ics], Line, Tlen, _, _) ->
    yystate(207, Ics, Line, Tlen+1, 19, Tlen);
yystate(223, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(223, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(223, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(223, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(223, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(223, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,223};
yystate(222, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(214, Ics, Line, Tlen+1, Action, Alen);
yystate(222, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,222};
yystate(221, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 12, Tlen);
yystate(221, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 12, Tlen);
yystate(221, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 12, Tlen);
yystate(221, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 12, Tlen);
yystate(221, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,221};
yystate(220, Ics, Line, Tlen, _, _) ->
    {18,Tlen,Ics,Line};
yystate(219, [108|Ics], Line, Tlen, _, _) ->
    yystate(235, Ics, Line, Tlen+1, 19, Tlen);
yystate(219, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(219, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(219, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(219, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(219, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(219, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,219};
yystate(218, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(218, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(218, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(218, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(218, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,218};
yystate(217, [108|Ics], Line, Tlen, _, _) ->
    yystate(233, Ics, Line, Tlen+1, 19, Tlen);
yystate(217, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(217, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(217, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(217, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(217, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(217, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,217};
yystate(216, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(200, Ics, Line, Tlen+1, Action, Alen);
yystate(216, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,216};
yystate(215, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(215, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(215, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(215, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,215};
yystate(214, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(214, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(222, Ics, Line, Tlen+1, Action, Alen);
yystate(214, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(198, Ics, Line, Tlen+1, Action, Alen);
yystate(214, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(214, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(214, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(214, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(214, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(214, Ics, Line, Tlen+1, Action, Alen);
yystate(214, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,214};
yystate(213, [61|Ics], Line, Tlen, _, _) ->
    yystate(229, Ics, Line, Tlen+1, 4, Tlen);
yystate(213, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line,213};
yystate(212, [111|Ics], Line, Tlen, _, _) ->
    yystate(196, Ics, Line, Tlen+1, 19, Tlen);
yystate(212, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(212, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(212, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(212, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(212, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(212, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,212};
yystate(211, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(227, Ics, Line, Tlen+1, Action, Alen);
yystate(211, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(211, Ics, Line+1, Tlen+1, Action, Alen);
yystate(211, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(211, Ics, Line, Tlen+1, Action, Alen);
yystate(211, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(211, Ics, Line, Tlen+1, Action, Alen);
yystate(211, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 91 ->
    yystate(211, Ics, Line, Tlen+1, Action, Alen);
yystate(211, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 123 ->
    yystate(211, Ics, Line, Tlen+1, Action, Alen);
yystate(211, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(211, Ics, Line, Tlen+1, Action, Alen);
yystate(211, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,211};
yystate(210, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(210, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(194, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(210, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(210, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,210};
yystate(209, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(201, Ics, Line, Tlen+1, Action, Alen);
yystate(209, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,209};
yystate(208, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(224, Ics, Line, Tlen+1, Action, Alen);
yystate(208, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,208};
yystate(207, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 9, Tlen);
yystate(207, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 9, Tlen);
yystate(207, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 9, Tlen);
yystate(207, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 9, Tlen);
yystate(207, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line,207};
yystate(206, [114|Ics], Line, Tlen, _, _) ->
    yystate(138, Ics, Line, Tlen+1, 19, Tlen);
yystate(206, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(206, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(206, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(206, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(206, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(206, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,206};
yystate(205, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(205, Ics, Line, Tlen+1, 16, Tlen);
yystate(205, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line,205};
yystate(204, [92|Ics], Line, Tlen, _, _) ->
    yystate(188, Ics, Line, Tlen+1, 18, Tlen);
yystate(204, [34|Ics], Line, Tlen, _, _) ->
    yystate(220, Ics, Line, Tlen+1, 18, Tlen);
yystate(204, [10|Ics], Line, Tlen, _, _) ->
    yystate(236, Ics, Line+1, Tlen+1, 18, Tlen);
yystate(204, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(236, Ics, Line, Tlen+1, 18, Tlen);
yystate(204, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 33 ->
    yystate(236, Ics, Line, Tlen+1, 18, Tlen);
yystate(204, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 91 ->
    yystate(236, Ics, Line, Tlen+1, 18, Tlen);
yystate(204, [C|Ics], Line, Tlen, _, _) when C >= 93 ->
    yystate(236, Ics, Line, Tlen+1, 18, Tlen);
yystate(204, Ics, Line, Tlen, _, _) ->
    {18,Tlen,Ics,Line,204};
yystate(203, [101|Ics], Line, Tlen, _, _) ->
    yystate(219, Ics, Line, Tlen+1, 13, Tlen);
yystate(203, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(203, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(203, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(203, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(203, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(203, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line,203};
yystate(202, [97|Ics], Line, Tlen, _, _) ->
    yystate(186, Ics, Line, Tlen+1, 19, Tlen);
yystate(202, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(202, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(202, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(202, [C|Ics], Line, Tlen, _, _) when C >= 98, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(202, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,202};
yystate(201, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(201, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(208, Ics, Line, Tlen+1, Action, Alen);
yystate(201, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(240, Ics, Line, Tlen+1, Action, Alen);
yystate(201, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(201, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(201, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(201, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(201, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(201, Ics, Line, Tlen+1, Action, Alen);
yystate(201, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,201};
yystate(200, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(200, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(248, Ics, Line, Tlen+1, Action, Alen);
yystate(200, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(216, Ics, Line, Tlen+1, Action, Alen);
yystate(200, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(200, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(200, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(200, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(200, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(200, Ics, Line, Tlen+1, Action, Alen);
yystate(200, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,200};
yystate(199, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(215, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(199, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(199, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(199, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,199};
yystate(198, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(182, Ics, Line, Tlen+1, Action, Alen);
yystate(198, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,198};
yystate(197, [101|Ics], Line, Tlen, _, _) ->
    yystate(181, Ics, Line, Tlen+1, 19, Tlen);
yystate(197, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(197, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(197, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(197, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(197, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(197, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,197};
yystate(196, [114|Ics], Line, Tlen, _, _) ->
    yystate(180, Ics, Line, Tlen+1, 19, Tlen);
yystate(196, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(196, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(196, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(196, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(196, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(196, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,196};
yystate(195, [C|Ics], Line, Tlen, Action, Alen) when C >= 32, C =< 126 ->
    yystate(179, Ics, Line, Tlen+1, Action, Alen);
yystate(195, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,195};
yystate(194, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(130, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(194, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(218, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(194, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(194, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,194};
yystate(193, [109|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 19, Tlen);
yystate(193, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(193, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(193, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(193, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 108 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(193, [C|Ics], Line, Tlen, _, _) when C >= 110, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(193, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,193};
yystate(192, Ics, Line, Tlen, _, _) ->
    {21,Tlen,Ics,Line};
yystate(191, [105|Ics], Line, Tlen, _, _) ->
    yystate(175, Ics, Line, Tlen+1, 19, Tlen);
yystate(191, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(191, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(191, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(191, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(191, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(191, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,191};
yystate(190, [111|Ics], Line, Tlen, _, _) ->
    yystate(206, Ics, Line, Tlen+1, 19, Tlen);
yystate(190, [105|Ics], Line, Tlen, _, _) ->
    yystate(230, Ics, Line, Tlen+1, 19, Tlen);
yystate(190, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(190, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(190, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(190, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(190, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 110 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(190, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(190, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,190};
yystate(189, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(173, Ics, Line, Tlen+1, 16, Tlen);
yystate(189, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line,189};
yystate(188, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(188, Ics, Line, Tlen+1, Action, Alen);
yystate(188, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(204, Ics, Line, Tlen+1, Action, Alen);
yystate(188, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(236, Ics, Line+1, Tlen+1, Action, Alen);
yystate(188, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(236, Ics, Line, Tlen+1, Action, Alen);
yystate(188, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(236, Ics, Line, Tlen+1, Action, Alen);
yystate(188, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(236, Ics, Line, Tlen+1, Action, Alen);
yystate(188, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(236, Ics, Line, Tlen+1, Action, Alen);
yystate(188, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,188};
yystate(187, [114|Ics], Line, Tlen, _, _) ->
    yystate(203, Ics, Line, Tlen+1, 19, Tlen);
yystate(187, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(187, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(187, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(187, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(187, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(187, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,187};
yystate(186, [112|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 19, Tlen);
yystate(186, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(186, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(186, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(186, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 111 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(186, [C|Ics], Line, Tlen, _, _) when C >= 113, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(186, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,186};
yystate(185, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(185, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(185, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(185, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(185, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(185, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,185};
yystate(184, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(168, Ics, Line, Tlen+1, Action, Alen);
yystate(184, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,184};
yystate(183, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(199, Ics, Line, Tlen+1, Action, Alen);
yystate(183, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(183, [32|Ics], Line, Tlen, Action, Alen) ->
    yystate(215, Ics, Line, Tlen+1, Action, Alen);
yystate(183, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(215, Ics, Line, Tlen+1, Action, Alen);
yystate(183, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line+1, Tlen+1, Action, Alen);
yystate(183, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(183, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 31 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(183, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 126 ->
    yystate(215, Ics, Line, Tlen+1, Action, Alen);
yystate(183, [C|Ics], Line, Tlen, Action, Alen) when C >= 127 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(183, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,183};
yystate(182, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(182, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(222, Ics, Line, Tlen+1, Action, Alen);
yystate(182, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(198, Ics, Line, Tlen+1, Action, Alen);
yystate(182, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(182, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(182, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(182, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(182, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(182, Ics, Line, Tlen+1, Action, Alen);
yystate(182, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,182};
yystate(181, [110|Ics], Line, Tlen, _, _) ->
    yystate(165, Ics, Line, Tlen+1, 19, Tlen);
yystate(181, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(181, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(181, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(181, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(181, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(181, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,181};
yystate(180, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(180, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(180, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(180, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(180, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line,180};
yystate(179, Ics, Line, Tlen, _, _) ->
    {14,Tlen,Ics,Line};
yystate(178, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(130, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(178, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(194, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(178, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(178, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,178};
yystate(177, [111|Ics], Line, Tlen, _, _) ->
    yystate(193, Ics, Line, Tlen+1, 19, Tlen);
yystate(177, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(177, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(177, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(177, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(177, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(177, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,177};
yystate(176, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(192, Ics, Line, Tlen+1, Action, Alen);
yystate(176, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,176};
yystate(175, [118|Ics], Line, Tlen, _, _) ->
    yystate(171, Ics, Line, Tlen+1, 19, Tlen);
yystate(175, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(175, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(175, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(175, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 117 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(175, [C|Ics], Line, Tlen, _, _) when C >= 119, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(175, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,175};
yystate(174, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 6, Tlen);
yystate(174, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 6, Tlen);
yystate(174, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 6, Tlen);
yystate(174, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 6, Tlen);
yystate(174, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line,174};
yystate(173, [35|Ics], Line, Tlen, _, _) ->
    yystate(109, Ics, Line, Tlen+1, 16, Tlen);
yystate(173, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(205, Ics, Line, Tlen+1, 16, Tlen);
yystate(173, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line,173};
yystate(172, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line};
yystate(171, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 11, Tlen);
yystate(171, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 11, Tlen);
yystate(171, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 11, Tlen);
yystate(171, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 11, Tlen);
yystate(171, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,171};
yystate(170, [105|Ics], Line, Tlen, _, _) ->
    yystate(154, Ics, Line, Tlen+1, 19, Tlen);
yystate(170, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(170, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(170, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(170, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(170, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(170, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,170};
yystate(169, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(169, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(208, Ics, Line, Tlen+1, Action, Alen);
yystate(169, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(240, Ics, Line, Tlen+1, Action, Alen);
yystate(169, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(169, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(209, Ics, Line, Tlen+1, Action, Alen);
yystate(169, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(169, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(169, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(169, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 54 ->
    yystate(137, Ics, Line, Tlen+1, Action, Alen);
yystate(169, [C|Ics], Line, Tlen, Action, Alen) when C >= 55, C =< 57 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(169, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,169};
yystate(168, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(168, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(248, Ics, Line, Tlen+1, Action, Alen);
yystate(168, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(216, Ics, Line, Tlen+1, Action, Alen);
yystate(168, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(168, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(168, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(168, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(168, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(168, Ics, Line, Tlen+1, Action, Alen);
yystate(168, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,168};
yystate(167, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(167, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(167, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line+1, Tlen+1, Action, Alen);
yystate(167, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(167, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(167, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(167, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(151, Ics, Line, Tlen+1, Action, Alen);
yystate(167, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(167, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(167, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,167};
yystate(166, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(166, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(166, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(166, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,166};
yystate(165, [103|Ics], Line, Tlen, _, _) ->
    yystate(149, Ics, Line, Tlen+1, 19, Tlen);
yystate(165, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(165, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(165, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(165, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(165, [C|Ics], Line, Tlen, _, _) when C >= 104, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(165, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,165};
yystate(164, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(164, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(164, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(164, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(164, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,164};
yystate(163, [123|Ics], Line, Tlen, _, _) ->
    yystate(228, Ics, Line, Tlen+1, 4, Tlen);
yystate(163, [82|Ics], Line, Tlen, _, _) ->
    yystate(147, Ics, Line, Tlen+1, 4, Tlen);
yystate(163, [80|Ics], Line, Tlen, _, _) ->
    yystate(44, Ics, Line, Tlen+1, 4, Tlen);
yystate(163, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line,163};
yystate(162, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(130, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(162, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 54 ->
    yystate(194, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [C|Ics], Line, Tlen, Action, Alen) when C >= 55, C =< 57 ->
    yystate(218, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(162, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(162, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,162};
yystate(161, [116|Ics], Line, Tlen, _, _) ->
    yystate(177, Ics, Line, Tlen+1, 19, Tlen);
yystate(161, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(161, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(161, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(161, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(161, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(161, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,161};
yystate(160, [60|Ics], Line, Tlen, _, _) ->
    yystate(18, Ics, Line, Tlen+1, 10, Tlen);
yystate(160, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(2, Ics, Line, Tlen+1, 10, Tlen);
yystate(160, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,160};
yystate(159, [121|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [122|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [120|Ics], Line, Tlen, _, _) ->
    yystate(143, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [115|Ics], Line, Tlen, _, _) ->
    yystate(119, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [111|Ics], Line, Tlen, _, _) ->
    yystate(103, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [110|Ics], Line, Tlen, _, _) ->
    yystate(87, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [97|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [C|Ics], Line, Tlen, _, _) when C >= 98, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 114 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, [C|Ics], Line, Tlen, _, _) when C >= 116, C =< 119 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(159, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,159};
yystate(158, [100|Ics], Line, Tlen, _, _) ->
    yystate(174, Ics, Line, Tlen+1, 19, Tlen);
yystate(158, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(158, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(158, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(158, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 99 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(158, [C|Ics], Line, Tlen, _, _) when C >= 101, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(158, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,158};
yystate(157, [35|Ics], Line, Tlen, _, _) ->
    yystate(109, Ics, Line, Tlen+1, 16, Tlen);
yystate(157, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(173, Ics, Line, Tlen+1, 16, Tlen);
yystate(157, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line,157};
yystate(156, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(172, Ics, Line, Tlen+1, Action, Alen);
yystate(156, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(156, Ics, Line, Tlen+1, Action, Alen);
yystate(156, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,156};
yystate(155, [109|Ics], Line, Tlen, _, _) ->
    yystate(171, Ics, Line, Tlen+1, 19, Tlen);
yystate(155, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(155, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(155, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(155, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 108 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(155, [C|Ics], Line, Tlen, _, _) when C >= 110, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(155, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,155};
yystate(154, [115|Ics], Line, Tlen, _, _) ->
    yystate(138, Ics, Line, Tlen+1, 19, Tlen);
yystate(154, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(154, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(154, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(154, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 114 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(154, [C|Ics], Line, Tlen, _, _) when C >= 116, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(154, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,154};
yystate(153, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(153, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(208, Ics, Line, Tlen+1, Action, Alen);
yystate(153, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(240, Ics, Line, Tlen+1, Action, Alen);
yystate(153, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(153, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(209, Ics, Line, Tlen+1, Action, Alen);
yystate(153, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(153, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(153, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(153, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(137, Ics, Line, Tlen+1, Action, Alen);
yystate(153, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,153};
yystate(152, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(152, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(248, Ics, Line, Tlen+1, Action, Alen);
yystate(152, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(216, Ics, Line, Tlen+1, Action, Alen);
yystate(152, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(152, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(184, Ics, Line, Tlen+1, Action, Alen);
yystate(152, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(152, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(152, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(152, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 54 ->
    yystate(128, Ics, Line, Tlen+1, Action, Alen);
yystate(152, [C|Ics], Line, Tlen, Action, Alen) when C >= 55, C =< 57 ->
    yystate(96, Ics, Line, Tlen+1, Action, Alen);
yystate(152, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,152};
yystate(151, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(151, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(151, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(151, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(151, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,151};
yystate(150, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(134, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(110, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(150, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(150, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(150, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,150};
yystate(149, [116|Ics], Line, Tlen, _, _) ->
    yystate(133, Ics, Line, Tlen+1, 19, Tlen);
yystate(149, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(149, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(149, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(149, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(149, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(149, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,149};
yystate(148, [104|Ics], Line, Tlen, _, _) ->
    yystate(132, Ics, Line, Tlen+1, 19, Tlen);
yystate(148, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(148, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(148, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(148, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 103 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(148, [C|Ics], Line, Tlen, _, _) when C >= 105, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(148, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,148};
yystate(147, [101|Ics], Line, Tlen, Action, Alen) ->
    yystate(131, Ics, Line, Tlen+1, Action, Alen);
yystate(147, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,147};
yystate(146, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(146, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(146, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(146, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(146, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,146};
yystate(145, [122|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(145, [121|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 19, Tlen);
yystate(145, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(145, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(145, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(145, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 120 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(145, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,145};
yystate(144, [61|Ics], Line, Tlen, Action, Alen) ->
    yystate(229, Ics, Line, Tlen+1, Action, Alen);
yystate(144, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,144};
yystate(143, [111|Ics], Line, Tlen, _, _) ->
    yystate(103, Ics, Line, Tlen+1, 19, Tlen);
yystate(143, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(143, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(143, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(143, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(143, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(143, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,143};
yystate(142, [114|Ics], Line, Tlen, _, _) ->
    yystate(158, Ics, Line, Tlen+1, 19, Tlen);
yystate(142, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(142, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(142, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(142, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(142, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(142, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,142};
yystate(141, [35|Ics], Line, Tlen, _, _) ->
    yystate(109, Ics, Line, Tlen+1, 16, Tlen);
yystate(141, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 54 ->
    yystate(173, Ics, Line, Tlen+1, 16, Tlen);
yystate(141, [C|Ics], Line, Tlen, _, _) when C >= 55, C =< 57 ->
    yystate(205, Ics, Line, Tlen+1, 16, Tlen);
yystate(141, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line,141};
yystate(140, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(156, Ics, Line, Tlen+1, Action, Alen);
yystate(140, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,140};
yystate(139, [100|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 19, Tlen);
yystate(139, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(139, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(139, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(139, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 99 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(139, [C|Ics], Line, Tlen, _, _) when C >= 101, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(139, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,139};
yystate(138, [116|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 19, Tlen);
yystate(138, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(138, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(138, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(138, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(138, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(138, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,138};
yystate(137, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(137, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(208, Ics, Line, Tlen+1, Action, Alen);
yystate(137, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(240, Ics, Line, Tlen+1, Action, Alen);
yystate(137, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(137, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(209, Ics, Line, Tlen+1, Action, Alen);
yystate(137, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(137, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(137, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(137, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(137, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,137};
yystate(136, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(136, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(248, Ics, Line, Tlen+1, Action, Alen);
yystate(136, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(216, Ics, Line, Tlen+1, Action, Alen);
yystate(136, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(136, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(184, Ics, Line, Tlen+1, Action, Alen);
yystate(136, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(136, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(136, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(136, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(128, Ics, Line, Tlen+1, Action, Alen);
yystate(136, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,136};
yystate(135, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(135, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(127, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(135, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(135, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,135};
yystate(134, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(134, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(134, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line+1, Tlen+1, Action, Alen);
yystate(134, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(134, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(134, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(134, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(118, Ics, Line, Tlen+1, Action, Alen);
yystate(134, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(134, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(134, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,134};
yystate(133, [104|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 19, Tlen);
yystate(133, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(133, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(133, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(133, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 103 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(133, [C|Ics], Line, Tlen, _, _) when C >= 105, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(133, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,133};
yystate(132, [101|Ics], Line, Tlen, _, _) ->
    yystate(116, Ics, Line, Tlen+1, 19, Tlen);
yystate(132, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(132, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(132, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(132, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(132, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(132, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,132};
yystate(131, [102|Ics], Line, Tlen, Action, Alen) ->
    yystate(115, Ics, Line, Tlen+1, Action, Alen);
yystate(131, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,131};
yystate(130, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(130, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(130, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line+1, Tlen+1, Action, Alen);
yystate(130, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(130, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(130, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(130, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(146, Ics, Line, Tlen+1, Action, Alen);
yystate(130, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(130, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(130, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,130};
yystate(129, [114|Ics], Line, Tlen, _, _) ->
    yystate(145, Ics, Line, Tlen+1, 19, Tlen);
yystate(129, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(129, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(129, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(129, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(129, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(129, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,129};
yystate(128, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(128, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(248, Ics, Line, Tlen+1, Action, Alen);
yystate(128, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(216, Ics, Line, Tlen+1, Action, Alen);
yystate(128, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(128, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(184, Ics, Line, Tlen+1, Action, Alen);
yystate(128, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(128, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(128, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(128, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(96, Ics, Line, Tlen+1, Action, Alen);
yystate(128, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,128};
yystate(127, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(127, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(151, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(127, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(127, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,127};
yystate(126, [111|Ics], Line, Tlen, _, _) ->
    yystate(142, Ics, Line, Tlen+1, 19, Tlen);
yystate(126, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(126, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(126, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(126, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(126, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(126, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,126};
yystate(125, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(125, Ics, Line, Tlen+1, 15, Tlen);
yystate(125, Ics, Line, Tlen, _, _) ->
    {15,Tlen,Ics,Line,125};
yystate(124, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(140, Ics, Line, Tlen+1, Action, Alen);
yystate(124, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(124, Ics, Line, Tlen+1, Action, Alen);
yystate(124, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,124};
yystate(123, [110|Ics], Line, Tlen, _, _) ->
    yystate(139, Ics, Line, Tlen+1, 19, Tlen);
yystate(123, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(123, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(123, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(123, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(123, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(123, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,123};
yystate(122, [110|Ics], Line, Tlen, _, _) ->
    yystate(106, Ics, Line, Tlen+1, 19, Tlen);
yystate(122, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(122, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(122, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(122, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(122, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(122, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,122};
yystate(121, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(121, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(208, Ics, Line, Tlen+1, Action, Alen);
yystate(121, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(240, Ics, Line, Tlen+1, Action, Alen);
yystate(121, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(121, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(121, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(121, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(121, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(137, Ics, Line, Tlen+1, Action, Alen);
yystate(121, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,121};
yystate(120, [62|Ics], Line, Tlen, _, _) ->
    yystate(228, Ics, Line, Tlen+1, 4, Tlen);
yystate(120, [61|Ics], Line, Tlen, _, _) ->
    yystate(229, Ics, Line, Tlen+1, 4, Tlen);
yystate(120, [60|Ics], Line, Tlen, _, _) ->
    yystate(229, Ics, Line, Tlen+1, 4, Tlen);
yystate(120, [58|Ics], Line, Tlen, _, _) ->
    yystate(144, Ics, Line, Tlen+1, 4, Tlen);
yystate(120, [47|Ics], Line, Tlen, _, _) ->
    yystate(144, Ics, Line, Tlen+1, 4, Tlen);
yystate(120, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line,120};
yystate(119, [114|Ics], Line, Tlen, _, _) ->
    yystate(171, Ics, Line, Tlen+1, 19, Tlen);
yystate(119, [108|Ics], Line, Tlen, _, _) ->
    yystate(171, Ics, Line, Tlen+1, 19, Tlen);
yystate(119, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(119, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(119, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(119, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(119, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 113 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(119, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(119, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,119};
yystate(118, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(134, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(110, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(118, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(118, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(118, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(118, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,118};
yystate(117, [115|Ics], Line, Tlen, _, _) ->
    yystate(101, Ics, Line, Tlen+1, 19, Tlen);
yystate(117, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(117, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(117, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(117, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 114 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(117, [C|Ics], Line, Tlen, _, _) when C >= 116, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(117, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,117};
yystate(116, [110|Ics], Line, Tlen, _, _) ->
    yystate(100, Ics, Line, Tlen+1, 19, Tlen);
yystate(116, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(116, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(116, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(116, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(116, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(116, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,116};
yystate(115, [60|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(115, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,115};
yystate(114, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(114, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(114, Ics, Line, Tlen+1, Action, Alen);
yystate(114, [C|Ics], Line, Tlen, Action, Alen) when C >= 123 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(114, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,114};
yystate(113, [97|Ics], Line, Tlen, _, _) ->
    yystate(129, Ics, Line, Tlen+1, 19, Tlen);
yystate(113, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(113, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(113, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(113, [C|Ics], Line, Tlen, _, _) when C >= 98, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(113, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,113};
yystate(112, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(112, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(248, Ics, Line, Tlen+1, Action, Alen);
yystate(112, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(216, Ics, Line, Tlen+1, Action, Alen);
yystate(112, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(112, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(112, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(112, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(112, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(128, Ics, Line, Tlen+1, Action, Alen);
yystate(112, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,112};
yystate(111, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(111, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(127, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(111, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(111, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,111};
yystate(110, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(110, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(110, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line+1, Tlen+1, Action, Alen);
yystate(110, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(110, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(110, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(110, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(110, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(94, Ics, Line, Tlen+1, Action, Alen);
yystate(110, [C|Ics], Line, Tlen, Action, Alen) when C >= 123 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(110, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,110};
yystate(109, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(125, Ics, Line, Tlen+1, Action, Alen);
yystate(109, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,109};
yystate(108, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(124, Ics, Line, Tlen+1, Action, Alen);
yystate(108, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,108};
yystate(107, [117|Ics], Line, Tlen, _, _) ->
    yystate(123, Ics, Line, Tlen+1, 19, Tlen);
yystate(107, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(107, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(107, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(107, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 116 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(107, [C|Ics], Line, Tlen, _, _) when C >= 118, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(107, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,107};
yystate(106, [116|Ics], Line, Tlen, _, _) ->
    yystate(90, Ics, Line, Tlen+1, 19, Tlen);
yystate(106, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(106, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(106, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(106, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(106, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(106, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,106};
yystate(105, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(208, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(240, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(105, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(105, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(105, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,105};
yystate(104, [61|Ics], Line, Tlen, _, _) ->
    yystate(229, Ics, Line, Tlen+1, 10, Tlen);
yystate(104, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,104};
yystate(103, [114|Ics], Line, Tlen, _, _) ->
    yystate(171, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(103, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,103};
yystate(102, [99|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 19, Tlen);
yystate(102, [97|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(102, [98|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(102, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(102, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(102, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(102, [C|Ics], Line, Tlen, _, _) when C >= 100, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(102, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,102};
yystate(101, [95|Ics], Line, Tlen, _, _) ->
    yystate(85, Ics, Line, Tlen+1, 19, Tlen);
yystate(101, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(101, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(101, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(101, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,101};
yystate(100, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 4, Tlen);
yystate(100, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 4, Tlen);
yystate(100, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 4, Tlen);
yystate(100, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 4, Tlen);
yystate(100, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line,100};
yystate(99, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(83, Ics, Line, Tlen+1, Action, Alen);
yystate(99, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,99};
yystate(98, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(98, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(98, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line+1, Tlen+1, Action, Alen);
yystate(98, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(98, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(98, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(98, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(98, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(114, Ics, Line, Tlen+1, Action, Alen);
yystate(98, [C|Ics], Line, Tlen, Action, Alen) when C >= 123 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(98, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,98};
yystate(97, [110|Ics], Line, Tlen, _, _) ->
    yystate(113, Ics, Line, Tlen+1, 19, Tlen);
yystate(97, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(97, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(97, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(97, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(97, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(97, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,97};
yystate(96, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(248, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(216, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(96, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(96, Ics, Line, Tlen+1, Action, Alen);
yystate(96, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,96};
yystate(95, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(95, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 54 ->
    yystate(127, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [C|Ics], Line, Tlen, Action, Alen) when C >= 55, C =< 57 ->
    yystate(151, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(95, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(95, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,95};
yystate(94, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(134, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(110, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(94, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(94, Ics, Line, Tlen+1, Action, Alen);
yystate(94, [C|Ics], Line, Tlen, Action, Alen) when C >= 123 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(94, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,94};
yystate(93, [61|Ics], Line, Tlen, _, _) ->
    yystate(228, Ics, Line, Tlen+1, 4, Tlen);
yystate(93, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line,93};
yystate(92, [60|Ics], Line, Tlen, Action, Alen) ->
    yystate(108, Ics, Line, Tlen+1, Action, Alen);
yystate(92, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,92};
yystate(91, [111|Ics], Line, Tlen, _, _) ->
    yystate(107, Ics, Line, Tlen+1, 19, Tlen);
yystate(91, [101|Ics], Line, Tlen, _, _) ->
    yystate(155, Ics, Line, Tlen+1, 19, Tlen);
yystate(91, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(91, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(91, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(91, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(91, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 110 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(91, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(91, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,91};
yystate(90, [101|Ics], Line, Tlen, _, _) ->
    yystate(74, Ics, Line, Tlen+1, 19, Tlen);
yystate(90, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(90, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(90, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(90, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(90, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(90, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,90};
yystate(89, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(89, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,89};
yystate(88, [95|Ics], Line, Tlen, _, _) ->
    yystate(88, Ics, Line, Tlen+1, 17, Tlen);
yystate(88, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(88, Ics, Line, Tlen+1, 17, Tlen);
yystate(88, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(88, Ics, Line, Tlen+1, 17, Tlen);
yystate(88, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(88, Ics, Line, Tlen+1, 17, Tlen);
yystate(88, Ics, Line, Tlen, _, _) ->
    {17,Tlen,Ics,Line,88};
yystate(87, [111|Ics], Line, Tlen, _, _) ->
    yystate(71, Ics, Line, Tlen+1, 19, Tlen);
yystate(87, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(87, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(87, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(87, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(87, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(87, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,87};
yystate(86, [110|Ics], Line, Tlen, _, _) ->
    yystate(102, Ics, Line, Tlen+1, 19, Tlen);
yystate(86, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(86, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(86, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(86, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(86, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(86, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,86};
yystate(85, [116|Ics], Line, Tlen, _, _) ->
    yystate(69, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [115|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [114|Ics], Line, Tlen, _, _) ->
    yystate(10, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [113|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [112|Ics], Line, Tlen, _, _) ->
    yystate(190, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [111|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [110|Ics], Line, Tlen, _, _) ->
    yystate(246, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [109|Ics], Line, Tlen, _, _) ->
    yystate(202, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [108|Ics], Line, Tlen, _, _) ->
    yystate(170, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [106|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [107|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [105|Ics], Line, Tlen, _, _) ->
    yystate(122, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [103|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [104|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [102|Ics], Line, Tlen, _, _) ->
    yystate(30, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [98|Ics], Line, Tlen, _, _) ->
    yystate(81, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [97|Ics], Line, Tlen, _, _) ->
    yystate(161, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [C|Ics], Line, Tlen, _, _) when C >= 99, C =< 101 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(85, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,85};
yystate(84, [114|Ics], Line, Tlen, _, _) ->
    yystate(68, Ics, Line, Tlen+1, 19, Tlen);
yystate(84, [108|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 19, Tlen);
yystate(84, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 113 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(84, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(84, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,84};
yystate(83, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(67, Ics, Line, Tlen+1, Action, Alen);
yystate(83, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(83, Ics, Line, Tlen+1, Action, Alen);
yystate(83, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,83};
yystate(82, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(82, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(82, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(82, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(82, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,82};
yystate(81, [105|Ics], Line, Tlen, _, _) ->
    yystate(97, Ics, Line, Tlen+1, 19, Tlen);
yystate(81, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(81, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(81, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(81, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(81, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(81, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,81};
yystate(80, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(96, Ics, Line, Tlen+1, Action, Alen);
yystate(80, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,80};
yystate(79, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(79, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(79, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(79, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,79};
yystate(78, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(162, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(178, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(210, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [48|Ics], Line, Tlen, Action, Alen) ->
    yystate(218, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(234, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [36|Ics], Line, Tlen, Action, Alen) ->
    yystate(250, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(150, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line+1, Tlen+1, Action, Alen);
yystate(78, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [C|Ics], Line, Tlen, Action, Alen) when C >= 37, C =< 44 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [C|Ics], Line, Tlen, Action, Alen) when C >= 52, C =< 57 ->
    yystate(194, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(78, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,78};
yystate(77, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line};
yystate(76, [116|Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen+1, Action, Alen);
yystate(76, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,76};
yystate(75, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 7, Tlen);
yystate(75, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 7, Tlen);
yystate(75, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 7, Tlen);
yystate(75, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 7, Tlen);
yystate(75, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,75};
yystate(74, [103|Ics], Line, Tlen, _, _) ->
    yystate(226, Ics, Line, Tlen+1, 19, Tlen);
yystate(74, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 104, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(74, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,74};
yystate(73, [C|Ics], Line, Tlen, Action, Alen) when C >= 32, C =< 126 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(73, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,73};
yystate(72, [115|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 19, Tlen);
yystate(72, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(72, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(72, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(72, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 114 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(72, [C|Ics], Line, Tlen, _, _) when C >= 116, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(72, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,72};
yystate(71, [116|Ics], Line, Tlen, _, _) ->
    yystate(171, Ics, Line, Tlen+1, 19, Tlen);
yystate(71, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(71, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(71, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(71, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(71, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(71, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,71};
yystate(70, [101|Ics], Line, Tlen, _, _) ->
    yystate(86, Ics, Line, Tlen+1, 19, Tlen);
yystate(70, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(70, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(70, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(70, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(70, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(70, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,70};
yystate(69, [117|Ics], Line, Tlen, _, _) ->
    yystate(53, Ics, Line, Tlen+1, 19, Tlen);
yystate(69, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(69, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(69, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(69, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 116 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(69, [C|Ics], Line, Tlen, _, _) when C >= 118, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(69, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,69};
yystate(68, [117|Ics], Line, Tlen, _, _) ->
    yystate(52, Ics, Line, Tlen+1, 19, Tlen);
yystate(68, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(68, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(68, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(68, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 116 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(68, [C|Ics], Line, Tlen, _, _) when C >= 118, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(68, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,68};
yystate(67, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(67, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,67};
yystate(66, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line+1, Tlen+1, Action, Alen);
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(82, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(66, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,66};
yystate(65, [110|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 19, Tlen);
yystate(65, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(65, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(65, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(65, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(65, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(65, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,65};
yystate(64, [C|Ics], Line, Tlen, Action, Alen) when C >= 32, C =< 126 ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(64, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,64};
yystate(63, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line+1, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(79, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(63, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,63};
yystate(62, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 45, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(62, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(62, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,62};
yystate(61, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(77, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(61, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,61};
yystate(60, [114|Ics], Line, Tlen, Action, Alen) ->
    yystate(76, Ics, Line, Tlen+1, Action, Alen);
yystate(60, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,60};
yystate(59, [102|Ics], Line, Tlen, _, _) ->
    yystate(75, Ics, Line, Tlen+1, 19, Tlen);
yystate(59, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 101 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(59, [C|Ics], Line, Tlen, _, _) when C >= 103, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(59, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,59};
yystate(58, [114|Ics], Line, Tlen, _, _) ->
    yystate(70, Ics, Line, Tlen+1, 19, Tlen);
yystate(58, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(58, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(58, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,58};
yystate(57, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(57, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(57, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line+1, Tlen+1, Action, Alen);
yystate(57, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(57, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(57, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(57, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(57, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,57};
yystate(56, [111|Ics], Line, Tlen, _, _) ->
    yystate(180, Ics, Line, Tlen+1, 19, Tlen);
yystate(56, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(56, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(56, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,56};
yystate(55, [110|Ics], Line, Tlen, _, _) ->
    yystate(39, Ics, Line, Tlen+1, 19, Tlen);
yystate(55, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(55, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(55, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,55};
yystate(54, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(54, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 123 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(54, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,54};
yystate(53, [112|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 19, Tlen);
yystate(53, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(53, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(53, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(53, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 111 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(53, [C|Ics], Line, Tlen, _, _) when C >= 113, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(53, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,53};
yystate(52, [110|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 19, Tlen);
yystate(52, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(52, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(52, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(52, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(52, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(52, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,52};
yystate(51, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(51, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(51, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,51};
yystate(50, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(208, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(240, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(225, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(185, Ics, Line+1, Tlen+1, Action, Alen);
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(185, Ics, Line, Tlen+1, Action, Alen);
yystate(50, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,50};
yystate(49, [111|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 19, Tlen);
yystate(49, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(49, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(49, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(49, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 110 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(49, [C|Ics], Line, Tlen, _, _) when C >= 112, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(49, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,49};
yystate(48, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(48, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(215, Ics, Line, Tlen+1, Action, Alen);
yystate(48, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line+1, Tlen+1, Action, Alen);
yystate(48, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(48, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(48, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(48, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(48, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,48};
yystate(47, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 123 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(47, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,47};
yystate(46, [114|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 19, Tlen);
yystate(46, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(46, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,46};
yystate(45, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(45, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,45};
yystate(44, [111|Ics], Line, Tlen, Action, Alen) ->
    yystate(60, Ics, Line, Tlen+1, Action, Alen);
yystate(44, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,44};
yystate(43, [108|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 19, Tlen);
yystate(43, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(43, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(43, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,43};
yystate(42, [101|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 19, Tlen);
yystate(42, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(42, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,42};
yystate(41, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(41, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,41};
yystate(40, [115|Ics], Line, Tlen, _, _) ->
    yystate(56, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 114 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, [C|Ics], Line, Tlen, _, _) when C >= 116, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(40, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,40};
yystate(39, [100|Ics], Line, Tlen, _, _) ->
    yystate(171, Ics, Line, Tlen+1, 19, Tlen);
yystate(39, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 99 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(39, [C|Ics], Line, Tlen, _, _) when C >= 101, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(39, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,39};
yystate(38, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line+1, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(54, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 123 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(38, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,38};
yystate(37, [108|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 19, Tlen);
yystate(37, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(37, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(37, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,37};
yystate(36, [99|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [97|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [98|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, [C|Ics], Line, Tlen, _, _) when C >= 100, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(36, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,36};
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(35, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,35};
yystate(34, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line+1, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(34, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,34};
yystate(33, [105|Ics], Line, Tlen, _, _) ->
    yystate(49, Ics, Line, Tlen+1, 19, Tlen);
yystate(33, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(33, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,33};
yystate(32, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(32, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(16, Ics, Line, Tlen+1, Action, Alen);
yystate(32, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(32, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line+1, Tlen+1, Action, Alen);
yystate(32, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(32, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(32, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(32, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(32, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(32, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,32};
yystate(31, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line+1, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(31, [C|Ics], Line, Tlen, Action, Alen) when C >= 123 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(31, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,31};
yystate(30, [117|Ics], Line, Tlen, _, _) ->
    yystate(14, Ics, Line, Tlen+1, 19, Tlen);
yystate(30, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 116 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 118, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(30, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,30};
yystate(29, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(29, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,29};
yystate(28, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line};
yystate(27, [101|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 19, Tlen);
yystate(27, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(27, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(27, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,27};
yystate(26, [102|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 19, Tlen);
yystate(26, [100|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(26, [101|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(26, [99|Ics], Line, Tlen, _, _) ->
    yystate(126, Ics, Line, Tlen+1, 19, Tlen);
yystate(26, [97|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(26, [98|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(26, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 103, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(26, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,26};
yystate(25, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line+1, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(25, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,25};
yystate(24, [108|Ics], Line, Tlen, _, _) ->
    yystate(40, Ics, Line, Tlen+1, 19, Tlen);
yystate(24, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 109, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(24, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,24};
yystate(23, [110|Ics], Line, Tlen, _, _) ->
    yystate(7, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [98|Ics], Line, Tlen, _, _) ->
    yystate(72, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [97|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [C|Ics], Line, Tlen, _, _) when C >= 99, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(23, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,23};
yystate(22, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line+1, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(22, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,22};
yystate(21, [101|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 19, Tlen);
yystate(21, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(21, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(21, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,21};
yystate(20, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 8, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 8, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 8, Tlen);
yystate(20, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 8, Tlen);
yystate(20, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line,20};
yystate(19, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(3, Ics, Line, Tlen+1, Action, Alen);
yystate(19, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(19, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,19};
yystate(18, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(176, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(169, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(153, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(121, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [48|Ics], Line, Tlen, Action, Alen) ->
    yystate(105, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [36|Ics], Line, Tlen, Action, Alen) ->
    yystate(73, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line+1, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 52, C =< 57 ->
    yystate(137, Ics, Line, Tlen+1, Action, Alen);
yystate(18, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,18};
yystate(17, [116|Ics], Line, Tlen, _, _) ->
    yystate(33, Ics, Line, Tlen+1, 19, Tlen);
yystate(17, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 115 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 117, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(17, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,17};
yystate(16, [92|Ics], Line, Tlen, _, _) ->
    yystate(48, Ics, Line, Tlen+1, 21, Tlen);
yystate(16, [34|Ics], Line, Tlen, _, _) ->
    yystate(257, Ics, Line, Tlen+1, 21, Tlen);
yystate(16, [10|Ics], Line, Tlen, _, _) ->
    yystate(241, Ics, Line+1, Tlen+1, 21, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, 21, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 33 ->
    yystate(241, Ics, Line, Tlen+1, 21, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, 21, Tlen);
yystate(16, [C|Ics], Line, Tlen, _, _) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, 21, Tlen);
yystate(16, Ics, Line, Tlen, _, _) ->
    {21,Tlen,Ics,Line,16};
yystate(15, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(231, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(247, Ics, Line+1, Tlen+1, Action, Alen);
yystate(15, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(247, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 43 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(15, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [C|Ics], Line, Tlen, Action, Alen) when C >= 59, C =< 61 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [C|Ics], Line, Tlen, Action, Alen) when C >= 63, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(15, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,15};
yystate(14, [110|Ics], Line, Tlen, _, _) ->
    yystate(1, Ics, Line, Tlen+1, 19, Tlen);
yystate(14, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(14, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(14, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(14, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(14, [C|Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(14, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,14};
yystate(13, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(13, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,13};
yystate(12, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(12, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(12, Ics, Line, Tlen+1, Action, Alen);
yystate(12, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,12};
yystate(11, [122|Ics], Line, Tlen, _, _) ->
    yystate(27, Ics, Line, Tlen+1, 19, Tlen);
yystate(11, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 121 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(11, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,11};
yystate(10, [101|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 19, Tlen);
yystate(10, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(10, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(10, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,10};
yystate(9, [92|Ics], Line, Tlen, _, _) ->
    yystate(57, Ics, Line, Tlen+1, 21, Tlen);
yystate(9, [34|Ics], Line, Tlen, _, _) ->
    yystate(50, Ics, Line, Tlen+1, 21, Tlen);
yystate(9, [10|Ics], Line, Tlen, _, _) ->
    yystate(34, Ics, Line+1, Tlen+1, 21, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, 21, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 33 ->
    yystate(34, Ics, Line, Tlen+1, 21, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, 21, Tlen);
yystate(9, [C|Ics], Line, Tlen, _, _) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, 21, Tlen);
yystate(9, Ics, Line, Tlen, _, _) ->
    {21,Tlen,Ics,Line,9};
yystate(8, [97|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 13, Tlen);
yystate(8, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 98, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 13, Tlen);
yystate(8, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line,8};
yystate(7, [100|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 19, Tlen);
yystate(7, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 99 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 101, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(7, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,7};
yystate(6, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line+1, Tlen+1, Action, Alen);
yystate(6, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 91 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(6, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,6};
yystate(5, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 5, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 5, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 5, Tlen);
yystate(5, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 5, Tlen);
yystate(5, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,5};
yystate(4, [105|Ics], Line, Tlen, _, _) ->
    yystate(11, Ics, Line, Tlen+1, 19, Tlen);
yystate(4, [101|Ics], Line, Tlen, _, _) ->
    yystate(43, Ics, Line, Tlen+1, 19, Tlen);
yystate(4, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 104 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 106, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(4, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,4};
yystate(3, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(12, Ics, Line, Tlen+1, Action, Alen);
yystate(3, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,3};
yystate(2, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(13, Ics, Line, Tlen+1, Action, Alen);
yystate(2, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(2, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,2};
yystate(1, [99|Ics], Line, Tlen, _, _) ->
    yystate(17, Ics, Line, Tlen+1, 19, Tlen);
yystate(1, [97|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(1, [98|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(1, [95|Ics], Line, Tlen, _, _) ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 100, C =< 122 ->
    yystate(164, Ics, Line, Tlen+1, 19, Tlen);
yystate(1, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,1};
yystate(0, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(0, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(257, Ics, Line, Tlen+1, Action, Alen);
yystate(0, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(241, Ics, Line+1, Tlen+1, Action, Alen);
yystate(0, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(0, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(0, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(0, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(15, Ics, Line, Tlen+1, Action, Alen);
yystate(0, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 91 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(0, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(241, Ics, Line, Tlen+1, Action, Alen);
yystate(0, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, _, _, _) ->
    yyaction_0();
yyaction(1, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_1(TokenChars, TokenLine);
yyaction(2, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_2(TokenChars, TokenLine);
yyaction(3, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_3(TokenChars, TokenLine);
yyaction(4, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_4(TokenChars, TokenLine);
yyaction(5, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_5(TokenChars, TokenLine);
yyaction(6, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_6(TokenChars, TokenLine);
yyaction(7, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_7(TokenChars, TokenLine);
yyaction(8, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_8(TokenChars, TokenLine);
yyaction(9, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_9(TokenChars, TokenLine);
yyaction(10, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_10(TokenChars, TokenLine);
yyaction(11, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_11(TokenChars, TokenLine);
yyaction(12, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_12(TokenChars, TokenLine);
yyaction(13, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_13(TokenChars, TokenLine);
yyaction(14, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_14(TokenChars, TokenLine);
yyaction(15, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_15(TokenChars, TokenLine);
yyaction(16, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_16(TokenChars, TokenLine);
yyaction(17, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_17(TokenChars, TokenLine);
yyaction(18, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_18(TokenChars, TokenLine);
yyaction(19, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_19(TokenChars, TokenLine);
yyaction(20, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_20(TokenChars, TokenLine);
yyaction(21, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_21(TokenChars, TokenLine);
yyaction(_, _, _, _) -> error.

-compile({inline,yyaction_0/0}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 44).
yyaction_0() ->
     skip_token .

-compile({inline,yyaction_1/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 47).
yyaction_1(TokenChars, TokenLine) ->
     { token, { pid, TokenLine, list_to_pid (TokenChars) } } .

-compile({inline,yyaction_2/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 50).
yyaction_2(TokenChars, TokenLine) ->
     { token, { ref, TokenLine, list_to_ref (TokenChars) } } .

-compile({inline,yyaction_3/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 53).
yyaction_3(TokenChars, TokenLine) ->
     { token, { port, TokenLine, list_to_port (TokenChars) } } .

-compile({inline,yyaction_4/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 56).
yyaction_4(TokenChars, TokenLine) ->
     { token, { to_atom (TokenChars), TokenLine } } .

-compile({inline,yyaction_5/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 59).
yyaction_5(TokenChars, TokenLine) ->
     { token, { type_test1, TokenLine, to_atom (TokenChars) } } .

-compile({inline,yyaction_6/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 62).
yyaction_6(TokenChars, TokenLine) ->
     { token, { type_isrec, TokenLine, to_atom (TokenChars) } } .

-compile({inline,yyaction_7/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 65).
yyaction_7(TokenChars, TokenLine) ->
     { token, { bif0, TokenLine, to_atom (TokenChars) } } .

-compile({inline,yyaction_8/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 68).
yyaction_8(TokenChars, TokenLine) ->
     { token, { bif1, TokenLine, to_atom (TokenChars) } } .

-compile({inline,yyaction_9/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 71).
yyaction_9(TokenChars, TokenLine) ->
     { token, { bif2, TokenLine, to_atom (TokenChars) } } .

-compile({inline,yyaction_10/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 74).
yyaction_10(TokenChars, TokenLine) ->
     { token, { comparison_op, TokenLine, to_atom (TokenChars) } } .

-compile({inline,yyaction_11/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 77).
yyaction_11(TokenChars, TokenLine) ->
     { token, { arithmetic_op, TokenLine, to_atom (TokenChars) } } .

-compile({inline,yyaction_12/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 80).
yyaction_12(TokenChars, TokenLine) ->
     { token, { boolean_op1, TokenLine, to_atom (TokenChars) } } .

-compile({inline,yyaction_13/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 83).
yyaction_13(TokenChars, TokenLine) ->
     { token, { boolean_op2, TokenLine, to_atom (TokenChars) } } .

-compile({inline,yyaction_14/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 86).
yyaction_14(TokenChars, TokenLine) ->
     { token, { int, TokenLine, char_to_int (TokenChars) } } .

-compile({inline,yyaction_15/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 89).
yyaction_15(TokenChars, TokenLine) ->
     { token, { int, TokenLine, radix_to_int (TokenChars) } } .

-compile({inline,yyaction_16/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 92).
yyaction_16(TokenChars, TokenLine) ->
     { token, { int, TokenLine, int_to_int (TokenChars) } } .

-compile({inline,yyaction_17/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 95).
yyaction_17(TokenChars, TokenLine) ->
     { token, { variable, TokenLine, TokenChars } } .

-compile({inline,yyaction_18/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 98).
yyaction_18(TokenChars, TokenLine) ->
     { token, { string, TokenLine, trim (TokenChars) } } .

-compile({inline,yyaction_19/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 101).
yyaction_19(TokenChars, TokenLine) ->
     { token, { atom, TokenLine, to_atom (TokenChars) } } .

-compile({inline,yyaction_20/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 104).
yyaction_20(TokenChars, TokenLine) ->
     { token, { atom, TokenLine, to_atom (trim (TokenChars)) } } .

-compile({inline,yyaction_21/2}).
-file("/Users/masse/git/redbug/src/redbug_lexer.xrl", 107).
yyaction_21(TokenChars, TokenLine) ->
     { token, { bin, TokenLine, to_binary (TokenChars) } } .

-file("/usr/local/Cellar/erlang/25.2/lib/erlang/lib/parsetools-2.4.1/include/leexinc.hrl", 313).
